#include <L298NX2.h>
#include <Servo.h>

// Pin definition
const unsigned int EN_A = 3;
const unsigned int IN1_A = 5;
const unsigned int IN2_A = 6;
const int sensorPin = A0;
const int buttonPin = 2;

const unsigned int IN1_B = 7;
const unsigned int IN2_B = 8;
const unsigned int EN_B = 11;

int val; // potentiometer value
int buttonState = 0; // button value
int prevState = 0;

// Initialize the motor
L298NX2 motors(EN_A, IN1_A, IN2_A, EN_B, IN1_B, IN2_B);

Servo myservo;  // create servo object to control a servo

bool servo = true;

void setup() {
  // Set speed for motor
  motors.setSpeed(90); // sets the speed of our L298N motor
  myservo.attach(10);  // attaches the servo on pin 10 to the servo object
  pinMode(buttonPin, INPUT); // initialize the pushbutton pin as an input:
  Serial.begin(9600);
}

void loop() {
  buttonState = digitalRead(buttonPin);
  val = analogRead(sensorPin);            // reads the value of the potentiometer (value between 0 and 1023)

  // If the button is clicked, switch between the two motors.
  if (buttonState == 0 and prevState == 1) {
    servo = not servo;
  }

  // Case where we are using the servo motor
  if (servo) {
    val = map(val, 0, 1023, 0, 180);     // scale it for use with the servo (value between 0 and 180)
    myservo.write(val);                  // sets the servo position according to the scaled value
    //delay(15);                           // waits for the servo to get there
  }
  // Case where we are using the L298N
  else {
    val = map(val, 0, 1023, -100, 100);     // scale it for use with the motor (value between -100 and 100)
  
    // Starts the motor in one direction should the potentiometer be turned clockwise
    if (val > 20) {
      motors.forward();
    }
    // Starts the motor in the other direction should the potentiometer be turned counterclockwise
    else if (val < -20) {
      motors.backward();
    }
    // Stops the motor if the potentiometer is near the middle
    else {
      motors.stop();
    }
  }
  prevState = buttonState;
  delay(15);
}
